==> haskell-aeson-1.5.4.1-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson
version:              1.5.4.1
visibility:           public
id:                   aeson-1.5.4.1-ILaja5MeYx9Akhe8KvMe35
key:                  aeson-1.5.4.1-ILaja5MeYx9Akhe8KvMe35
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bos/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  b080168db6efa2bff0f421bef2434029
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser
    Data.Aeson.Parser.Internal Data.Aeson.QQ.Simple Data.Aeson.TH
    Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Encoding.Builder Data.Aeson.Internal.Functions
    Data.Aeson.Parser.Unescape Data.Aeson.Parser.Time
    Data.Aeson.Types.FromJSON Data.Aeson.Types.Generic
    Data.Aeson.Types.ToJSON Data.Aeson.Types.Class
    Data.Aeson.Types.Internal Data.Attoparsec.Time
    Data.Attoparsec.Time.Internal Data.Aeson.Parser.UnescapePure

import-dirs:          /usr/lib/ghc-8.10.3/site-local/aeson-1.5.4.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/aeson-1.5.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/aeson-1.5.4.1
hs-libraries:         HSaeson-1.5.4.1-ILaja5MeYx9Akhe8KvMe35
depends:
    attoparsec-0.13.2.4-EKPYlpfO7iaKzKjSdYGJKg base-4.14.1.0
    base-compat-batteries-0.11.2-HOtaMJNyZcPDfag3AYvyr4
    bytestring-0.10.12.0 containers-0.6.2.1
    data-fix-0.3.0-IZlIB7iC0pe3P3yQwY45Rt deepseq-1.4.4.0
    dlist-1.0-2aybcLB5DHr8SwtOEInjWL ghc-prim-0.6.1
    hashable-1.3.0.0-EOCizfvfdumIxsTFbMrwv1
    primitive-0.7.1.0-5iVCuttZpQKRKYySoUE3v
    scientific-0.3.6.2-I52IrFKHZJGKH6LImos2wb
    strict-0.4.0.1-BI4x6ZRe15f8STJUsQGon4
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C template-haskell-2.16.0.0
    text-1.2.4.1 th-abstraction-0.4.1.0-A7JgjUrazebFmefKqpqS0Q
    these-1.1.1.1-AHH57e3h2an1M6i55vVKg3 time-1.9.3
    time-compat-1.9.5-Eb7ozE5QFF34bnZNtlzkkh
    unordered-containers-0.2.13.0-CZ1lolzXKqq6TlKZBOiERd
    uuid-types-1.0.3-3PMxrmBbMUIG2Ja3tgMNPt
    vector-0.12.1.2-GaSyd0oSBV34z4313IZO9j

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-1.5.4.1-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson
version:              1.5.4.1
visibility:           public
id:                   aeson-1.5.4.1-KEDpjWRN4PnwanaxkUvMN
key:                  aeson-1.5.4.1-KEDpjWRN4PnwanaxkUvMN
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bos/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  1ad15b815a259b023fb93093101251ae
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser
    Data.Aeson.Parser.Internal Data.Aeson.QQ.Simple Data.Aeson.TH
    Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Encoding.Builder Data.Aeson.Internal.Functions
    Data.Aeson.Parser.Unescape Data.Aeson.Parser.Time
    Data.Aeson.Types.FromJSON Data.Aeson.Types.Generic
    Data.Aeson.Types.ToJSON Data.Aeson.Types.Class
    Data.Aeson.Types.Internal Data.Attoparsec.Time
    Data.Attoparsec.Time.Internal Data.Aeson.Parser.UnescapePure

import-dirs:          /usr/lib/ghc-8.10.3/site-local/aeson-1.5.4.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/aeson-1.5.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/aeson-1.5.4.1
hs-libraries:         HSaeson-1.5.4.1-KEDpjWRN4PnwanaxkUvMN
depends:
    attoparsec-0.13.2.4-2xssqE3sbQuJGvEDlr5HPN base-4.14.1.0
    base-compat-batteries-0.11.2-85LmND914Dd4jlReEwAYjW
    bytestring-0.10.12.0 containers-0.6.2.1
    data-fix-0.3.0-CdGYrpH8MVmBKVTtsDv2lX deepseq-1.4.4.0
    dlist-1.0-6kDZmBgcnBNJPMF2JCpbw9 ghc-prim-0.6.1
    hashable-1.3.0.0-2hTNCY6h24LBZEHqacy9BZ
    primitive-0.7.1.0-Lv6PNgiQvA0Ky6DJvjsHti
    scientific-0.3.6.2-4T9tdREaNXCARYmknnW6vk
    strict-0.4.0.1-1rSCYD8PAc34KeN20TQdsB
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C template-haskell-2.16.0.0
    text-1.2.4.1 th-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG
    these-1.1.1.1-ssD5KFAH8qHxv95Yi76ro time-1.9.3
    time-compat-1.9.5-FU1YkxuJOet8xx9UhOBRly
    unordered-containers-0.2.13.0-602GQuCMlfP9kZrcq9TZvH
    uuid-types-1.0.3-Gcby7cPtQKTCWkja4RsVD3
    vector-0.12.1.2-5hszrBfumemIu85xm28LVC

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
